/***
 *
 *       Program ...:  Interface CA-Clipper 5.2 - IBM HOST
 *       File.......:  EXAMPLE.PRG
 *       Author.....:  Mauro Tronto
 *       Creation...:  20/07/94
 *
 *       /*  ( Revision )  */
 *       Data/Ora...:  07/11/94    12.21.48
 *
 *       Blinker versione 3.01:
 *       
 *       BLINKER FI esempio LIB BLXCLP52, BLI3270 BLI EXE EXT
 *
 *       CA-Exospace versione 1.0f:
 *       
 *       EXOSPACE FI esempio LIB EXOSPACE, EXO3270
 *
 */

#include "x3270.ch"

/***
 *
 *      PROCEDURE. : Main()
 *      Author ... : Mauro Tronto 21/07/94
 *      
 *      Entry Point
 *
 *      Operation that MUST BE execute prior to establish connection
 *      between host session and your applications:
 *
 *      1. Load your 3270 emulation software.
 *
 *      2. Switch PC session
 *
 *      3. Load API 3270 module interface. This module is include in your
 *         emulation software ( HLLAPI.EXE or EEHLLAPI.EXE or other. )
 *
 *      4. Run your Clipper application(s)
 *
 */
PROCEDURE Main()

   LOCAL GetList := {}
   LOCAL psID    := " ", CodErr, nPos

   CLS

   @ 1,0 SAY "Example of using library x3270 for Clipper v1.0"
   @ 2,0 SAY "Software by Mauro Tronto (c) - Ancona, 1994"
   @ 3,0 SAY "All rights reserved"
   @ 4,0 SAY ""
   @ 5,0 SAY "Enter one character short name of the target presentation space:" GET psID PICT "!"
   READ

   IF LASTKEY() == 27 .OR. EMPTY( psID )
      QUIT
   ENDIF

   // First step ALWAYS required: establish connection with host session
   IF HConnect( psID )
      ? "Connession OK ... !"

   ELSE
      // The service HError() inform you about any problem!
      codErr := HError()

      DO CASE

         CASE ( codErr == 1 )
            ? "An invalid presentation space ID was specified!"

         CASE ( codErr == 3 )
            ? "Successful connection of the presentation space WsCtrl was achieved"

         CASE ( codErr == 4 )
            ? "Successful connection was achieved, but the presentation space is busy"

         CASE ( codErr == 5 )
            ? "Successful connection was achieved, but the presentation space is locked (input inhibited)"

         CASE ( codErr == 9 )
            ? "A system error was encountered"

         CASE ( codErr == 11 )
            ? "This resource is unavailable. The request PS space is in use by another session"

      ENDCASE

      QUIT

   ENDIF

   // Example step two: send a string of keystrokes to the connected presentation space
   MsgService( "Service  HSendKey():", "Send a string of keystrokes to the connected presentation space" )
   HSendKey( "Ciao!" )
   MsgStop()

  /*
   *   Examine the current connected presentation space for the occurrence of a specified string
   *   ATTENTION: the string can contain a null character.
   *   For translation you can use a macro defined in x3270.ch _NULL_TO_BLANK_()
   *   and _BLANK_TO_NULL_()
   */
   MsgService( "Service  HSearchPS():", "Examine the current connected PS for the occurrence of a specified string" )

   IF (nPos := HSearchPS( "EXAMPLE OF STRING" )) > 0
      ? "String Found at position " + ALLTRIM( STR(nPos) )
   ELSE
      ? "String NOT Found!"
   ENDIF ; MsgStop()

   MsgService( "Service  HCopyPS():", "Copy the entire connected presentation space" )
   ? HCopyPS() ; INKEY( 3 )

   MsgService( "Service  HCopyPS():", "Copy 8 byte start from position 10 (if there are)" )
   ? HCopyPS( 10,8 ) ; INKEY( 3 )

   MsgService( "Service  HCopyPS():", "Show all character start from posizion 1000" )
   ? HCopyPS( 1000 ) ; INKEY( 3 )

   MsgService( "Service  HSendToPS():", "Send a string at position 10 (if possible)" )
   ? HSendToPS( "CSSF LOGOFF", 10 ) ; MsgStop()

   // Shut down connection!
   HDisconnect()

   // Italian Thanks!.
   ? "Grazie dell'uso e .... Buon Lavoro!"

RETURN

/***
 *
 *      FUNZIONE . :
 *      Autore ... : Mauro Tronto 21/07/94
 *      
 *      Send a message on screen and wait
 *
 */
FUNCTION MsgStop()
   ? "Press any key to continue or jump to session host for verify the result" ; INKEY(0)
RETURN ( NIL )

/***
 *
 *      FUNZIONE . : MsgService()
 *      Autore ... : Mauro Tronto 07/11/94
 *      
 *
 *
 */
FUNCTION MsgService( cFunc, cDesc )

   CLS
   @ 0,0 SAY PADR( cFunc,80 ) COLOR "W+/B"
   @ 1,0 SAY cDesc COLOR "W+/N"
   INKEY( 3 )

RETURN ( NIL )
